Module archive
compak
0.1.2
Module archive
Module Items
Structs
Functions
In crate compak
compak
Module
archive
Structs

Archive
A handle to an archive file that can be extracted.
Functions

extract_
archive
Convenience function to extract an archive in a single call.